@@ -1,10 +1,8 @@
 package HTML::Tidy::Message;
 
+use 5.010001;
 use warnings;
 use strict;
-use overload
-    q{""} => \&as_string,
-    fallback => 'sounds like a good idea';
 
 =head1 NAME
 
@@ -139,7 +137,7 @@ sub text    { my $self = shift; return $self->{_text} }
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005-2013 Andy Lester.
+Copyright 2005-2017 Andy Lester.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License v2.0.
